@@ -21,10 +21,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.'''
 
 """aiodagpi - An asynchronous python API wrapper for Dagpi : https://dagpi.tk"""
-from ._http import http
-from .exceptions import *
-from .client import aiodagpiclient
 
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 __author__ = 'Raj Sharma <yrsharma@icloud.com>'
 __all__ = []
